# Batches

Batches module provides functionality for batch processing operations.

## Overview

The batches module contains abstractions and implementations for handling batch operations in your application.

## Components

- **Abstract**: Base abstract classes for batch operations
- **Batch**: Core batch functionality
- **Mapped**: Mapped batch implementations
- **SQLAlchemy**: SQLAlchemy-specific batch implementations
